@@ -85,8 +85,8 @@ static bool dbusCall(const QString &service,
         {
             Notification::notify(
                                     QObject::tr("Power Manager Error"),
-                                    QObject::tr("QDBusInterface is invalid") + QL1S("\n\n") + service + QL1C(' ') + path + QL1C(' ') + interface + QL1C(' ') + method,
-                                    QL1S("lxqt-logo.png"));
+                                    QObject::tr("QDBusInterface is invalid") + QL1SV("\n\n") + service + QL1C(' ') + path + QL1C(' ') + interface + QL1C(' ') + method,
+                                    QL1SV("lxqt-logo.png"));
         }
         return false;
     }
@@ -100,8 +100,8 @@ static bool dbusCall(const QString &service,
         {
             Notification::notify(
                                     QObject::tr("Power Manager Error (D-BUS call)"),
-                                    msg.errorName() + QL1S("\n\n") + msg.errorMessage(),
-                                    QL1S("lxqt-logo.png"));
+                                    msg.errorName() + QL1SV("\n\n") + msg.errorMessage(),
+                                    QL1SV("lxqt-logo.png"));
         }
     }
 
@@ -135,8 +135,8 @@ static bool dbusCallSystemd(const QString &service,
         {
             Notification::notify(
                                     QObject::tr("Power Manager Error"),
-                                    QObject::tr("QDBusInterface is invalid") + QL1S("\n\n") + service + QL1C(' ') + path + QL1C(' ')+ interface + QL1C(' ') + method,
-                                    QL1S("lxqt-logo.png"));
+                                    QObject::tr("QDBusInterface is invalid") + QL1SV("\n\n") + service + QL1C(' ') + path + QL1C(' ')+ interface + QL1C(' ') + method,
+                                    QL1SV("lxqt-logo.png"));
         }
         return false;
     }
@@ -150,8 +150,8 @@ static bool dbusCallSystemd(const QString &service,
         {
             Notification::notify(
                                     QObject::tr("Power Manager Error (D-BUS call)"),
-                                    msg.errorName() + QL1S("\n\n") + msg.errorMessage(),
-                                    QL1S("lxqt-logo.png"));
+                                    msg.errorName() + QL1SV("\n\n") + msg.errorMessage(),
+                                    QL1SV("lxqt-logo.png"));
         }
     }
 
@@ -161,7 +161,7 @@ static bool dbusCallSystemd(const QString &service,
 
     QString response = msg.arguments().constFirst().toString();
     qDebug() << "systemd:" << method << "=" << response;
-    return response == QL1S("yes") || response == QL1S("challenge");
+    return response == QL1SV("yes") || response == QL1SV("challenge");
 }
 
 
@@ -187,7 +187,7 @@ bool dbusGetProperty(const QString &service,
         return false;
     }
 
-    QDBusMessage msg = dbus.call(QL1S("Get"), dbus.interface(), property);
+    QDBusMessage msg = dbus.call(QL1SV("Get"), dbus.interface(), property);
 
     if (!msg.errorName().isEmpty())
     {
@@ -237,13 +237,13 @@ bool UPowerProvider::canAction(Power::Action action) const
     switch (action)
     {
     case Power::PowerHibernate:
-        property = QL1S("CanHibernate");
-        command  = QL1S("HibernateAllowed");
+        property = QL1SV("CanHibernate");
+        command  = QL1SV("HibernateAllowed");
         break;
 
     case Power::PowerSuspend:
-        property = QL1S("CanSuspend");
-        command  = QL1S("SuspendAllowed");
+        property = QL1SV("CanSuspend");
+        command  = QL1SV("SuspendAllowed");
         break;
 
     default:
@@ -251,17 +251,17 @@ bool UPowerProvider::canAction(Power::Action action) const
     }
 
     return  dbusGetProperty(  // Whether the system is able to hibernate.
-                QL1S(UPOWER_SERVICE),
-                QL1S(UPOWER_PATH),
-                QL1S(PROPERTIES_INTERFACE),
+                QL1SV(UPOWER_SERVICE),
+                QL1SV(UPOWER_PATH),
+                QL1SV(PROPERTIES_INTERFACE),
                 QDBusConnection::systemBus(),
                 property
             )
             &&
             dbusCall( // Check if the caller has (or can get) the PolicyKit privilege to call command.
-                QL1S(UPOWER_SERVICE),
-                QL1S(UPOWER_PATH),
-                QL1S(UPOWER_INTERFACE),
+                QL1SV(UPOWER_SERVICE),
+                QL1SV(UPOWER_PATH),
+                QL1SV(UPOWER_INTERFACE),
                 QDBusConnection::systemBus(),
                 command,
                 // canAction should be always silent because it can freeze
@@ -279,11 +279,11 @@ bool UPowerProvider::doAction(Power::Action action)
     switch (action)
     {
     case Power::PowerHibernate:
-        command = QL1S("Hibernate");
+        command = QL1SV("Hibernate");
         break;
 
     case Power::PowerSuspend:
-        command = QL1S("Suspend");
+        command = QL1SV("Suspend");
         break;
 
     default:
@@ -291,9 +291,9 @@ bool UPowerProvider::doAction(Power::Action action)
     }
 
 
-    return dbusCall(QL1S(UPOWER_SERVICE),
-             QL1S(UPOWER_PATH),
-             QL1S(UPOWER_INTERFACE),
+    return dbusCall(QL1SV(UPOWER_SERVICE),
+             QL1SV(UPOWER_PATH),
+             QL1SV(UPOWER_INTERFACE),
              QDBusConnection::systemBus(),
              command );
 }
@@ -318,28 +318,28 @@ bool ConsoleKitProvider::canAction(Power::Action action) const
     switch (action)
     {
     case Power::PowerReboot:
-        command = QL1S("CanReboot");
+        command = QL1SV("CanReboot");
         break;
 
     case Power::PowerShutdown:
-        command = QL1S("CanPowerOff");
+        command = QL1SV("CanPowerOff");
         break;
 
     case Power::PowerHibernate:
-        command  = QL1S("CanHibernate");
+        command  = QL1SV("CanHibernate");
         break;
 
     case Power::PowerSuspend:
-        command  = QL1S("CanSuspend");
+        command  = QL1SV("CanSuspend");
         break;
 
     default:
         return false;
     }
 
-    return dbusCallSystemd(QL1S(CONSOLEKIT_SERVICE),
-                    QL1S(CONSOLEKIT_PATH),
-                    QL1S(CONSOLEKIT_INTERFACE),
+    return dbusCallSystemd(QL1SV(CONSOLEKIT_SERVICE),
+                    QL1SV(CONSOLEKIT_PATH),
+                    QL1SV(CONSOLEKIT_INTERFACE),
                     QDBusConnection::systemBus(),
                     command,
                     false,
@@ -357,28 +357,28 @@ bool ConsoleKitProvider::doAction(Power::Action action)
     switch (action)
     {
     case Power::PowerReboot:
-        command = QL1S("Reboot");
+        command = QL1SV("Reboot");
         break;
 
     case Power::PowerShutdown:
-        command = QL1S("PowerOff");
+        command = QL1SV("PowerOff");
         break;
 
     case Power::PowerHibernate:
-        command = QL1S("Hibernate");
+        command = QL1SV("Hibernate");
         break;
 
     case Power::PowerSuspend:
-        command = QL1S("Suspend");
+        command = QL1SV("Suspend");
         break;
 
     default:
         return false;
     }
 
-    return dbusCallSystemd(QL1S(CONSOLEKIT_SERVICE),
-                QL1S(CONSOLEKIT_PATH),
-                QL1S(CONSOLEKIT_INTERFACE),
+    return dbusCallSystemd(QL1SV(CONSOLEKIT_SERVICE),
+                QL1SV(CONSOLEKIT_PATH),
+                QL1SV(CONSOLEKIT_INTERFACE),
                 QDBusConnection::systemBus(),
                 command,
                 true
@@ -407,28 +407,28 @@ bool SystemdProvider::canAction(Power::Action action) const
     switch (action)
     {
     case Power::PowerReboot:
-        command = QL1S("CanReboot");
+        command = QL1SV("CanReboot");
         break;
 
     case Power::PowerShutdown:
-        command = QL1S("CanPowerOff");
+        command = QL1SV("CanPowerOff");
         break;
 
     case Power::PowerSuspend:
-        command = QL1S("CanSuspend");
+        command = QL1SV("CanSuspend");
         break;
 
     case Power::PowerHibernate:
-        command = QL1S("CanHibernate");
+        command = QL1SV("CanHibernate");
         break;
 
     default:
         return false;
     }
 
-    return dbusCallSystemd(QL1S(SYSTEMD_SERVICE),
-                    QL1S(SYSTEMD_PATH),
-                    QL1S(SYSTEMD_INTERFACE),
+    return dbusCallSystemd(QL1SV(SYSTEMD_SERVICE),
+                    QL1SV(SYSTEMD_PATH),
+                    QL1SV(SYSTEMD_INTERFACE),
                     QDBusConnection::systemBus(),
                     command,
                     false,
@@ -447,28 +447,28 @@ bool SystemdProvider::doAction(Power::Action action)
     switch (action)
     {
     case Power::PowerReboot:
-        command = QL1S("Reboot");
+        command = QL1SV("Reboot");
         break;
 
     case Power::PowerShutdown:
-        command = QL1S("PowerOff");
+        command = QL1SV("PowerOff");
         break;
 
     case Power::PowerSuspend:
-        command = QL1S("Suspend");
+        command = QL1SV("Suspend");
         break;
 
     case Power::PowerHibernate:
-        command = QL1S("Hibernate");
+        command = QL1SV("Hibernate");
         break;
 
     default:
         return false;
     }
 
-    return dbusCallSystemd(QL1S(SYSTEMD_SERVICE),
-             QL1S(SYSTEMD_PATH),
-             QL1S(SYSTEMD_INTERFACE),
+    return dbusCallSystemd(QL1SV(SYSTEMD_SERVICE),
+             QL1SV(SYSTEMD_PATH),
+             QL1SV(SYSTEMD_INTERFACE),
              QDBusConnection::systemBus(),
              command,
              true
@@ -494,20 +494,20 @@ bool LXQtProvider::canAction(Power::Action action) const
     switch (action)
     {
         case Power::PowerLogout:
-            command = QL1S("canLogout");
+            command = QL1SV("canLogout");
             break;
         case Power::PowerReboot:
-            command = QL1S("canReboot");
+            command = QL1SV("canReboot");
             break;
         case Power::PowerShutdown:
-            command = QL1S("canPowerOff");
+            command = QL1SV("canPowerOff");
             break;
         default:
             return false;
     }
 
     // there can be case when lxqtsession-session does not run
-    return dbusCall(QL1S(LXQT_SERVICE), QL1S(LXQT_PATH), QL1S(LXQT_INTERFACE),
+    return dbusCall(QL1SV(LXQT_SERVICE), QL1SV(LXQT_PATH), QL1SV(LXQT_INTERFACE),
             QDBusConnection::sessionBus(), command,
             PowerProvider::DontCheckDBUS);
 }
@@ -519,21 +519,21 @@ bool LXQtProvider::doAction(Power::Action action)
     switch (action)
     {
         case Power::PowerLogout:
-            command = QL1S("logout");
+            command = QL1SV("logout");
             break;
         case Power::PowerReboot:
-            command = QL1S("reboot");
+            command = QL1SV("reboot");
             break;
         case Power::PowerShutdown:
-            command = QL1S("powerOff");
+            command = QL1SV("powerOff");
             break;
         default:
             return false;
     }
 
-    return dbusCall(QL1S(LXQT_SERVICE),
-             QL1S(LXQT_PATH),
-             QL1S(LXQT_INTERFACE),
+    return dbusCall(QL1SV(LXQT_SERVICE),
+             QL1SV(LXQT_PATH),
+             QL1SV(LXQT_INTERFACE),
              QDBusConnection::sessionBus(),
              command
             );
@@ -611,7 +611,7 @@ bool HalProvider::doAction(Power::Action action)
  ************************************************/
 CustomProvider::CustomProvider(QObject *parent):
     PowerProvider(parent),
-    mSettings(QL1S("power"))
+    mSettings(QL1SV("power"))
 {
 }
 
@@ -622,25 +622,25 @@ bool CustomProvider::canAction(Power::Action action) const
     switch (action)
     {
     case Power::PowerShutdown:
-        return mSettings.contains(QL1S("shutdownCommand"));
+        return mSettings.contains(QL1SV("shutdownCommand"));
 
     case Power::PowerReboot:
-        return mSettings.contains(QL1S("rebootCommand"));
+        return mSettings.contains(QL1SV("rebootCommand"));
 
     case Power::PowerHibernate:
-        return mSettings.contains(QL1S("hibernateCommand"));
+        return mSettings.contains(QL1SV("hibernateCommand"));
 
     case Power::PowerSuspend:
-        return mSettings.contains(QL1S("suspendCommand"));
+        return mSettings.contains(QL1SV("suspendCommand"));
 
     case Power::PowerLogout:
-        return mSettings.contains(QL1S("logoutCommand"));
+        return mSettings.contains(QL1SV("logoutCommand"));
 
     case Power::PowerMonitorOff:
-        return mSettings.contains(QL1S("monitorOffCommand"));
+        return mSettings.contains(QL1SV("monitorOffCommand"));
 
     case Power::PowerShowLeaveDialog:
-        return mSettings.contains(QL1S("showLeaveDialogCommand"));
+        return mSettings.contains(QL1SV("showLeaveDialogCommand"));
 
     default:
         return false;
@@ -654,31 +654,31 @@ bool CustomProvider::doAction(Power::Action action)
     switch(action)
     {
     case Power::PowerShutdown:
-        command = mSettings.value(QL1S("shutdownCommand")).toString();
+        command = mSettings.value(QL1SV("shutdownCommand")).toString();
         break;
 
     case Power::PowerReboot:
-        command = mSettings.value(QL1S("rebootCommand")).toString();
+        command = mSettings.value(QL1SV("rebootCommand")).toString();
         break;
 
     case Power::PowerHibernate:
-        command = mSettings.value(QL1S("hibernateCommand")).toString();
+        command = mSettings.value(QL1SV("hibernateCommand")).toString();
         break;
 
     case Power::PowerSuspend:
-        command = mSettings.value(QL1S("suspendCommand")).toString();
+        command = mSettings.value(QL1SV("suspendCommand")).toString();
         break;
 
     case Power::PowerLogout:
-        command = mSettings.value(QL1S("logoutCommand")).toString();
+        command = mSettings.value(QL1SV("logoutCommand")).toString();
         break;
 
     case Power::PowerMonitorOff:
-        command = mSettings.value(QL1S("monitorOffCommand")).toString();
+        command = mSettings.value(QL1SV("monitorOffCommand")).toString();
         break;
 
     case Power::PowerShowLeaveDialog:
-        command = mSettings.value(QL1S("showLeaveDialogCommand")).toString();
+        command = mSettings.value(QL1SV("showLeaveDialogCommand")).toString();
         break;
 
     default:
